=====================
UCSM Mechanism Driver
=====================
The following list of variables are used by the cisco_ucsm mechanism driver.
A variable's default value can be changed by adding it to the configuration
file included on the neutron-server command line. The sample ucsm configuration
file is described here,
:doc:`samples/ml2-ucsm`.

.. show-options::

   networking_cisco.ucsm
